'''OpenGL extension NV.vertex_program

Overview (from the spec)
	
	Unextended OpenGL mandates a certain set of configurable per-vertex
	computations defining vertex transformation, texture coordinate
	generation and transformation, and lighting.  Several extensions
	have added further per-vertex computations to OpenGL.  For example,
	extensions have defined new texture coordinate generation modes
	(ARB_texture_cube_map, NV_texgen_reflection, NV_texgen_emboss), new
	vertex transformation modes (EXT_vertex_weighting), new lighting modes
	(OpenGL 1.2's separate specular and rescale normal functionality),
	several modes for fog distance generation (NV_fog_distance), and
	eye-distance point size attenuation (EXT_point_parameters).
	
	Each such extension adds a small set of relatively inflexible
	per-vertex computations.
	
	This inflexibility is in contrast to the typical flexibility provided
	by the underlying programmable floating point engines (whether
	micro-coded vertex engines, DSPs, or CPUs) that are traditionally used
	to implement OpenGL's per-vertex computations.  The purpose of this
	extension is to expose to the OpenGL application writer a significant
	degree of per-vertex programmability for computing vertex parameters.
	
	For the purposes of discussing this extension, a vertex program is
	a sequence of floating-point 4-component vector operations that
	determines how a set of program parameters (defined outside of
	OpenGL's begin/end pair) and an input set of per-vertex parameters
	are transformed to a set of per-vertex output parameters.
	
	The per-vertex computations for standard OpenGL given a particular
	set of lighting and texture coordinate generation modes (along with
	any state for extensions defining per-vertex computations) is, in
	essence, a vertex program.  However, the sequence of operations is
	defined implicitly by the current OpenGL state settings rather than
	defined explicitly as a sequence of instructions.
	
	This extension provides an explicit mechanism for defining vertex
	program instruction sequences for application-defined vertex programs.
	In order to define such vertex programs, this extension defines
	a vertex programming model including a floating-point 4-component
	vector instruction set and a relatively large set of floating-point
	4-component registers.
	
	The extension's vertex programming model is designed for efficient
	hardware implementation and to support a wide variety of vertex
	programs.  By design, the entire set of existing vertex programs
	defined by existing OpenGL per-vertex computation extensions can be
	implemented using the extension's vertex programming model.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/NV/vertex_program.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_vertex_program'
GL_VERTEX_PROGRAM_NV = constant.Constant( 'GL_VERTEX_PROGRAM_NV', 0x8620 )
glget.addGLGetConstant( GL_VERTEX_PROGRAM_NV, (1,) )
GL_VERTEX_STATE_PROGRAM_NV = constant.Constant( 'GL_VERTEX_STATE_PROGRAM_NV', 0x8621 )
GL_ATTRIB_ARRAY_SIZE_NV = constant.Constant( 'GL_ATTRIB_ARRAY_SIZE_NV', 0x8623 )
GL_ATTRIB_ARRAY_STRIDE_NV = constant.Constant( 'GL_ATTRIB_ARRAY_STRIDE_NV', 0x8624 )
GL_ATTRIB_ARRAY_TYPE_NV = constant.Constant( 'GL_ATTRIB_ARRAY_TYPE_NV', 0x8625 )
GL_CURRENT_ATTRIB_NV = constant.Constant( 'GL_CURRENT_ATTRIB_NV', 0x8626 )
GL_PROGRAM_LENGTH_NV = constant.Constant( 'GL_PROGRAM_LENGTH_NV', 0x8627 )
GL_PROGRAM_STRING_NV = constant.Constant( 'GL_PROGRAM_STRING_NV', 0x8628 )
GL_MODELVIEW_PROJECTION_NV = constant.Constant( 'GL_MODELVIEW_PROJECTION_NV', 0x8629 )
GL_IDENTITY_NV = constant.Constant( 'GL_IDENTITY_NV', 0x862A )
GL_INVERSE_NV = constant.Constant( 'GL_INVERSE_NV', 0x862B )
GL_TRANSPOSE_NV = constant.Constant( 'GL_TRANSPOSE_NV', 0x862C )
GL_INVERSE_TRANSPOSE_NV = constant.Constant( 'GL_INVERSE_TRANSPOSE_NV', 0x862D )
GL_MAX_TRACK_MATRIX_STACK_DEPTH_NV = constant.Constant( 'GL_MAX_TRACK_MATRIX_STACK_DEPTH_NV', 0x862E )
glget.addGLGetConstant( GL_MAX_TRACK_MATRIX_STACK_DEPTH_NV, (1,) )
GL_MAX_TRACK_MATRICES_NV = constant.Constant( 'GL_MAX_TRACK_MATRICES_NV', 0x862F )
glget.addGLGetConstant( GL_MAX_TRACK_MATRICES_NV, (1,) )
GL_MATRIX0_NV = constant.Constant( 'GL_MATRIX0_NV', 0x8630 )
GL_MATRIX1_NV = constant.Constant( 'GL_MATRIX1_NV', 0x8631 )
GL_MATRIX2_NV = constant.Constant( 'GL_MATRIX2_NV', 0x8632 )
GL_MATRIX3_NV = constant.Constant( 'GL_MATRIX3_NV', 0x8633 )
GL_MATRIX4_NV = constant.Constant( 'GL_MATRIX4_NV', 0x8634 )
GL_MATRIX5_NV = constant.Constant( 'GL_MATRIX5_NV', 0x8635 )
GL_MATRIX6_NV = constant.Constant( 'GL_MATRIX6_NV', 0x8636 )
GL_MATRIX7_NV = constant.Constant( 'GL_MATRIX7_NV', 0x8637 )
GL_CURRENT_MATRIX_STACK_DEPTH_NV = constant.Constant( 'GL_CURRENT_MATRIX_STACK_DEPTH_NV', 0x8640 )
glget.addGLGetConstant( GL_CURRENT_MATRIX_STACK_DEPTH_NV, (1,) )
GL_CURRENT_MATRIX_NV = constant.Constant( 'GL_CURRENT_MATRIX_NV', 0x8641 )
glget.addGLGetConstant( GL_CURRENT_MATRIX_NV, (4,4) )
GL_VERTEX_PROGRAM_POINT_SIZE_NV = constant.Constant( 'GL_VERTEX_PROGRAM_POINT_SIZE_NV', 0x8642 )
glget.addGLGetConstant( GL_VERTEX_PROGRAM_POINT_SIZE_NV, (1,) )
GL_VERTEX_PROGRAM_TWO_SIDE_NV = constant.Constant( 'GL_VERTEX_PROGRAM_TWO_SIDE_NV', 0x8643 )
glget.addGLGetConstant( GL_VERTEX_PROGRAM_TWO_SIDE_NV, (1,) )
GL_PROGRAM_PARAMETER_NV = constant.Constant( 'GL_PROGRAM_PARAMETER_NV', 0x8644 )
GL_ATTRIB_ARRAY_POINTER_NV = constant.Constant( 'GL_ATTRIB_ARRAY_POINTER_NV', 0x8645 )
GL_PROGRAM_TARGET_NV = constant.Constant( 'GL_PROGRAM_TARGET_NV', 0x8646 )
GL_PROGRAM_RESIDENT_NV = constant.Constant( 'GL_PROGRAM_RESIDENT_NV', 0x8647 )
GL_TRACK_MATRIX_NV = constant.Constant( 'GL_TRACK_MATRIX_NV', 0x8648 )
GL_TRACK_MATRIX_TRANSFORM_NV = constant.Constant( 'GL_TRACK_MATRIX_TRANSFORM_NV', 0x8649 )
GL_VERTEX_PROGRAM_BINDING_NV = constant.Constant( 'GL_VERTEX_PROGRAM_BINDING_NV', 0x864A )
glget.addGLGetConstant( GL_VERTEX_PROGRAM_BINDING_NV, (1,) )
GL_PROGRAM_ERROR_POSITION_NV = constant.Constant( 'GL_PROGRAM_ERROR_POSITION_NV', 0x864B )
glget.addGLGetConstant( GL_PROGRAM_ERROR_POSITION_NV, (1,) )
GL_VERTEX_ATTRIB_ARRAY0_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY0_NV', 0x8650 )
GL_VERTEX_ATTRIB_ARRAY1_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY1_NV', 0x8651 )
GL_VERTEX_ATTRIB_ARRAY2_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY2_NV', 0x8652 )
GL_VERTEX_ATTRIB_ARRAY3_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY3_NV', 0x8653 )
GL_VERTEX_ATTRIB_ARRAY4_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY4_NV', 0x8654 )
GL_VERTEX_ATTRIB_ARRAY5_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY5_NV', 0x8655 )
GL_VERTEX_ATTRIB_ARRAY6_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY6_NV', 0x8656 )
GL_VERTEX_ATTRIB_ARRAY7_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY7_NV', 0x8657 )
GL_VERTEX_ATTRIB_ARRAY8_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY8_NV', 0x8658 )
GL_VERTEX_ATTRIB_ARRAY9_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY9_NV', 0x8659 )
GL_VERTEX_ATTRIB_ARRAY10_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY10_NV', 0x865A )
GL_VERTEX_ATTRIB_ARRAY11_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY11_NV', 0x865B )
GL_VERTEX_ATTRIB_ARRAY12_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY12_NV', 0x865C )
GL_VERTEX_ATTRIB_ARRAY13_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY13_NV', 0x865D )
GL_VERTEX_ATTRIB_ARRAY14_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY14_NV', 0x865E )
GL_VERTEX_ATTRIB_ARRAY15_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY15_NV', 0x865F )
GL_MAP1_VERTEX_ATTRIB0_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB0_4_NV', 0x8660 )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB0_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB1_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB1_4_NV', 0x8661 )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB1_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB2_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB2_4_NV', 0x8662 )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB2_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB3_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB3_4_NV', 0x8663 )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB3_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB4_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB4_4_NV', 0x8664 )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB4_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB5_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB5_4_NV', 0x8665 )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB5_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB6_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB6_4_NV', 0x8666 )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB6_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB7_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB7_4_NV', 0x8667 )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB7_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB8_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB8_4_NV', 0x8668 )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB8_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB9_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB9_4_NV', 0x8669 )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB9_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB10_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB10_4_NV', 0x866A )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB10_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB11_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB11_4_NV', 0x866B )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB11_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB12_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB12_4_NV', 0x866C )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB12_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB13_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB13_4_NV', 0x866D )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB13_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB14_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB14_4_NV', 0x866E )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB14_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB15_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB15_4_NV', 0x866F )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB15_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB0_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB0_4_NV', 0x8670 )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB0_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB1_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB1_4_NV', 0x8671 )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB1_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB2_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB2_4_NV', 0x8672 )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB2_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB3_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB3_4_NV', 0x8673 )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB3_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB4_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB4_4_NV', 0x8674 )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB4_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB5_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB5_4_NV', 0x8675 )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB5_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB6_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB6_4_NV', 0x8676 )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB6_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB7_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB7_4_NV', 0x8677 )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB7_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB8_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB8_4_NV', 0x8678 )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB8_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB9_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB9_4_NV', 0x8679 )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB9_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB10_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB10_4_NV', 0x867A )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB10_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB11_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB11_4_NV', 0x867B )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB11_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB12_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB12_4_NV', 0x867C )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB12_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB13_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB13_4_NV', 0x867D )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB13_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB14_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB14_4_NV', 0x867E )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB14_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB15_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB15_4_NV', 0x867F )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB15_4_NV, (4,) )
glAreProgramsResidentNV = platform.createExtensionFunction( 
	'glAreProgramsResidentNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=constants.GLboolean, 
	argTypes=(constants.GLsizei, arrays.GLuintArray, ctypes.POINTER(constants.GLboolean),),
	doc = 'glAreProgramsResidentNV( GLsizei(n), GLuintArray(programs), POINTER(constants.GLboolean)(residences) ) -> constants.GLboolean',
	argNames = ('n', 'programs', 'residences',),
)

glBindProgramNV = platform.createExtensionFunction( 
	'glBindProgramNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint,),
	doc = 'glBindProgramNV( GLenum(target), GLuint(id) ) -> None',
	argNames = ('target', 'id',),
)

glDeleteProgramsNV = platform.createExtensionFunction( 
	'glDeleteProgramsNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLsizei, arrays.GLuintArray,),
	doc = 'glDeleteProgramsNV( GLsizei(n), GLuintArray(programs) ) -> None',
	argNames = ('n', 'programs',),
)

glExecuteProgramNV = platform.createExtensionFunction( 
	'glExecuteProgramNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, arrays.GLfloatArray,),
	doc = 'glExecuteProgramNV( GLenum(target), GLuint(id), GLfloatArray(params) ) -> None',
	argNames = ('target', 'id', 'params',),
)

glGenProgramsNV = platform.createExtensionFunction( 
	'glGenProgramsNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLsizei, arrays.GLuintArray,),
	doc = 'glGenProgramsNV( GLsizei(n), GLuintArray(programs) ) -> None',
	argNames = ('n', 'programs',),
)

glGetProgramParameterdvNV = platform.createExtensionFunction( 
	'glGetProgramParameterdvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, constants.GLenum, arrays.GLdoubleArray,),
	doc = 'glGetProgramParameterdvNV( GLenum(target), GLuint(index), GLenum(pname), GLdoubleArray(params) ) -> None',
	argNames = ('target', 'index', 'pname', 'params',),
)

glGetProgramParameterfvNV = platform.createExtensionFunction( 
	'glGetProgramParameterfvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, constants.GLenum, arrays.GLfloatArray,),
	doc = 'glGetProgramParameterfvNV( GLenum(target), GLuint(index), GLenum(pname), GLfloatArray(params) ) -> None',
	argNames = ('target', 'index', 'pname', 'params',),
)

glGetProgramivNV = platform.createExtensionFunction( 
	'glGetProgramivNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLenum, arrays.GLintArray,),
	doc = 'glGetProgramivNV( GLuint(id), GLenum(pname), GLintArray(params) ) -> None',
	argNames = ('id', 'pname', 'params',),
)

glGetProgramStringNV = platform.createExtensionFunction( 
	'glGetProgramStringNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLenum, arrays.GLubyteArray,),
	doc = 'glGetProgramStringNV( GLuint(id), GLenum(pname), GLubyteArray(program) ) -> None',
	argNames = ('id', 'pname', 'program',),
)

glGetTrackMatrixivNV = platform.createExtensionFunction( 
	'glGetTrackMatrixivNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, constants.GLenum, arrays.GLintArray,),
	doc = 'glGetTrackMatrixivNV( GLenum(target), GLuint(address), GLenum(pname), GLintArray(params) ) -> None',
	argNames = ('target', 'address', 'pname', 'params',),
)

glGetVertexAttribdvNV = platform.createExtensionFunction( 
	'glGetVertexAttribdvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLenum, arrays.GLdoubleArray,),
	doc = 'glGetVertexAttribdvNV( GLuint(index), GLenum(pname), GLdoubleArray(params) ) -> None',
	argNames = ('index', 'pname', 'params',),
)

glGetVertexAttribfvNV = platform.createExtensionFunction( 
	'glGetVertexAttribfvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLenum, arrays.GLfloatArray,),
	doc = 'glGetVertexAttribfvNV( GLuint(index), GLenum(pname), GLfloatArray(params) ) -> None',
	argNames = ('index', 'pname', 'params',),
)

glGetVertexAttribivNV = platform.createExtensionFunction( 
	'glGetVertexAttribivNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLenum, arrays.GLintArray,),
	doc = 'glGetVertexAttribivNV( GLuint(index), GLenum(pname), GLintArray(params) ) -> None',
	argNames = ('index', 'pname', 'params',),
)

glGetVertexAttribPointervNV = platform.createExtensionFunction( 
	'glGetVertexAttribPointervNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLenum, ctypes.POINTER(ctypes.c_void_p),),
	doc = 'glGetVertexAttribPointervNV( GLuint(index), GLenum(pname), POINTER(ctypes.c_void_p)(pointer) ) -> None',
	argNames = ('index', 'pname', 'pointer',),
)

glIsProgramNV = platform.createExtensionFunction( 
	'glIsProgramNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=constants.GLboolean, 
	argTypes=(constants.GLuint,),
	doc = 'glIsProgramNV( GLuint(id) ) -> constants.GLboolean',
	argNames = ('id',),
)

glLoadProgramNV = platform.createExtensionFunction( 
	'glLoadProgramNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, constants.GLsizei, arrays.GLubyteArray,),
	doc = 'glLoadProgramNV( GLenum(target), GLuint(id), GLsizei(len), GLubyteArray(program) ) -> None',
	argNames = ('target', 'id', 'len', 'program',),
)

glProgramParameter4dNV = platform.createExtensionFunction( 
	'glProgramParameter4dNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, constants.GLdouble, constants.GLdouble, constants.GLdouble, constants.GLdouble,),
	doc = 'glProgramParameter4dNV( GLenum(target), GLuint(index), GLdouble(x), GLdouble(y), GLdouble(z), GLdouble(w) ) -> None',
	argNames = ('target', 'index', 'x', 'y', 'z', 'w',),
)

glProgramParameter4dvNV = platform.createExtensionFunction( 
	'glProgramParameter4dvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, arrays.GLdoubleArray,),
	doc = 'glProgramParameter4dvNV( GLenum(target), GLuint(index), GLdoubleArray(v) ) -> None',
	argNames = ('target', 'index', 'v',),
)

glProgramParameter4fNV = platform.createExtensionFunction( 
	'glProgramParameter4fNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glProgramParameter4fNV( GLenum(target), GLuint(index), GLfloat(x), GLfloat(y), GLfloat(z), GLfloat(w) ) -> None',
	argNames = ('target', 'index', 'x', 'y', 'z', 'w',),
)

glProgramParameter4fvNV = platform.createExtensionFunction( 
	'glProgramParameter4fvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, arrays.GLfloatArray,),
	doc = 'glProgramParameter4fvNV( GLenum(target), GLuint(index), GLfloatArray(v) ) -> None',
	argNames = ('target', 'index', 'v',),
)

glProgramParameters4dvNV = platform.createExtensionFunction( 
	'glProgramParameters4dvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, constants.GLuint, arrays.GLdoubleArray,),
	doc = 'glProgramParameters4dvNV( GLenum(target), GLuint(index), GLuint(count), GLdoubleArray(v) ) -> None',
	argNames = ('target', 'index', 'count', 'v',),
)

glProgramParameters4fvNV = platform.createExtensionFunction( 
	'glProgramParameters4fvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, constants.GLuint, arrays.GLfloatArray,),
	doc = 'glProgramParameters4fvNV( GLenum(target), GLuint(index), GLuint(count), GLfloatArray(v) ) -> None',
	argNames = ('target', 'index', 'count', 'v',),
)

glRequestResidentProgramsNV = platform.createExtensionFunction( 
	'glRequestResidentProgramsNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLsizei, arrays.GLuintArray,),
	doc = 'glRequestResidentProgramsNV( GLsizei(n), GLuintArray(programs) ) -> None',
	argNames = ('n', 'programs',),
)

glTrackMatrixNV = platform.createExtensionFunction( 
	'glTrackMatrixNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, constants.GLenum, constants.GLenum,),
	doc = 'glTrackMatrixNV( GLenum(target), GLuint(address), GLenum(matrix), GLenum(transform) ) -> None',
	argNames = ('target', 'address', 'matrix', 'transform',),
)

glVertexAttribPointerNV = platform.createExtensionFunction( 
	'glVertexAttribPointerNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLint, constants.GLenum, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glVertexAttribPointerNV( GLuint(index), GLint(fsize), GLenum(type), GLsizei(stride), c_void_p(pointer) ) -> None',
	argNames = ('index', 'fsize', 'type', 'stride', 'pointer',),
)

glVertexAttrib1dNV = platform.createExtensionFunction( 
	'glVertexAttrib1dNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLdouble,),
	doc = 'glVertexAttrib1dNV( GLuint(index), GLdouble(x) ) -> None',
	argNames = ('index', 'x',),
)

glVertexAttrib1dvNV = platform.createExtensionFunction( 
	'glVertexAttrib1dvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLdoubleArray,),
	doc = 'glVertexAttrib1dvNV( GLuint(index), GLdoubleArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib1fNV = platform.createExtensionFunction( 
	'glVertexAttrib1fNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLfloat,),
	doc = 'glVertexAttrib1fNV( GLuint(index), GLfloat(x) ) -> None',
	argNames = ('index', 'x',),
)

glVertexAttrib1fvNV = platform.createExtensionFunction( 
	'glVertexAttrib1fvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLfloatArray,),
	doc = 'glVertexAttrib1fvNV( GLuint(index), GLfloatArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib1sNV = platform.createExtensionFunction( 
	'glVertexAttrib1sNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLshort,),
	doc = 'glVertexAttrib1sNV( GLuint(index), GLshort(x) ) -> None',
	argNames = ('index', 'x',),
)

glVertexAttrib1svNV = platform.createExtensionFunction( 
	'glVertexAttrib1svNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLshortArray,),
	doc = 'glVertexAttrib1svNV( GLuint(index), GLshortArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib2dNV = platform.createExtensionFunction( 
	'glVertexAttrib2dNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLdouble, constants.GLdouble,),
	doc = 'glVertexAttrib2dNV( GLuint(index), GLdouble(x), GLdouble(y) ) -> None',
	argNames = ('index', 'x', 'y',),
)

glVertexAttrib2dvNV = platform.createExtensionFunction( 
	'glVertexAttrib2dvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLdoubleArray,),
	doc = 'glVertexAttrib2dvNV( GLuint(index), GLdoubleArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib2fNV = platform.createExtensionFunction( 
	'glVertexAttrib2fNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLfloat, constants.GLfloat,),
	doc = 'glVertexAttrib2fNV( GLuint(index), GLfloat(x), GLfloat(y) ) -> None',
	argNames = ('index', 'x', 'y',),
)

glVertexAttrib2fvNV = platform.createExtensionFunction( 
	'glVertexAttrib2fvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLfloatArray,),
	doc = 'glVertexAttrib2fvNV( GLuint(index), GLfloatArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib2sNV = platform.createExtensionFunction( 
	'glVertexAttrib2sNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLshort, constants.GLshort,),
	doc = 'glVertexAttrib2sNV( GLuint(index), GLshort(x), GLshort(y) ) -> None',
	argNames = ('index', 'x', 'y',),
)

glVertexAttrib2svNV = platform.createExtensionFunction( 
	'glVertexAttrib2svNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLshortArray,),
	doc = 'glVertexAttrib2svNV( GLuint(index), GLshortArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib3dNV = platform.createExtensionFunction( 
	'glVertexAttrib3dNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLdouble, constants.GLdouble, constants.GLdouble,),
	doc = 'glVertexAttrib3dNV( GLuint(index), GLdouble(x), GLdouble(y), GLdouble(z) ) -> None',
	argNames = ('index', 'x', 'y', 'z',),
)

glVertexAttrib3dvNV = platform.createExtensionFunction( 
	'glVertexAttrib3dvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLdoubleArray,),
	doc = 'glVertexAttrib3dvNV( GLuint(index), GLdoubleArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib3fNV = platform.createExtensionFunction( 
	'glVertexAttrib3fNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glVertexAttrib3fNV( GLuint(index), GLfloat(x), GLfloat(y), GLfloat(z) ) -> None',
	argNames = ('index', 'x', 'y', 'z',),
)

glVertexAttrib3fvNV = platform.createExtensionFunction( 
	'glVertexAttrib3fvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLfloatArray,),
	doc = 'glVertexAttrib3fvNV( GLuint(index), GLfloatArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib3sNV = platform.createExtensionFunction( 
	'glVertexAttrib3sNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLshort, constants.GLshort, constants.GLshort,),
	doc = 'glVertexAttrib3sNV( GLuint(index), GLshort(x), GLshort(y), GLshort(z) ) -> None',
	argNames = ('index', 'x', 'y', 'z',),
)

glVertexAttrib3svNV = platform.createExtensionFunction( 
	'glVertexAttrib3svNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLshortArray,),
	doc = 'glVertexAttrib3svNV( GLuint(index), GLshortArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib4dNV = platform.createExtensionFunction( 
	'glVertexAttrib4dNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLdouble, constants.GLdouble, constants.GLdouble, constants.GLdouble,),
	doc = 'glVertexAttrib4dNV( GLuint(index), GLdouble(x), GLdouble(y), GLdouble(z), GLdouble(w) ) -> None',
	argNames = ('index', 'x', 'y', 'z', 'w',),
)

glVertexAttrib4dvNV = platform.createExtensionFunction( 
	'glVertexAttrib4dvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLdoubleArray,),
	doc = 'glVertexAttrib4dvNV( GLuint(index), GLdoubleArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib4fNV = platform.createExtensionFunction( 
	'glVertexAttrib4fNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glVertexAttrib4fNV( GLuint(index), GLfloat(x), GLfloat(y), GLfloat(z), GLfloat(w) ) -> None',
	argNames = ('index', 'x', 'y', 'z', 'w',),
)

glVertexAttrib4fvNV = platform.createExtensionFunction( 
	'glVertexAttrib4fvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLfloatArray,),
	doc = 'glVertexAttrib4fvNV( GLuint(index), GLfloatArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib4sNV = platform.createExtensionFunction( 
	'glVertexAttrib4sNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLshort, constants.GLshort, constants.GLshort, constants.GLshort,),
	doc = 'glVertexAttrib4sNV( GLuint(index), GLshort(x), GLshort(y), GLshort(z), GLshort(w) ) -> None',
	argNames = ('index', 'x', 'y', 'z', 'w',),
)

glVertexAttrib4svNV = platform.createExtensionFunction( 
	'glVertexAttrib4svNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLshortArray,),
	doc = 'glVertexAttrib4svNV( GLuint(index), GLshortArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib4ubNV = platform.createExtensionFunction( 
	'glVertexAttrib4ubNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLubyte, constants.GLubyte, constants.GLubyte, constants.GLubyte,),
	doc = 'glVertexAttrib4ubNV( GLuint(index), GLubyte(x), GLubyte(y), GLubyte(z), GLubyte(w) ) -> None',
	argNames = ('index', 'x', 'y', 'z', 'w',),
)

glVertexAttrib4ubvNV = platform.createExtensionFunction( 
	'glVertexAttrib4ubvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLubyteArray,),
	doc = 'glVertexAttrib4ubvNV( GLuint(index), GLubyteArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttribs1dvNV = platform.createExtensionFunction( 
	'glVertexAttribs1dvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLsizei, arrays.GLdoubleArray,),
	doc = 'glVertexAttribs1dvNV( GLuint(index), GLsizei(count), GLdoubleArray(v) ) -> None',
	argNames = ('index', 'count', 'v',),
)

glVertexAttribs1fvNV = platform.createExtensionFunction( 
	'glVertexAttribs1fvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLsizei, arrays.GLfloatArray,),
	doc = 'glVertexAttribs1fvNV( GLuint(index), GLsizei(count), GLfloatArray(v) ) -> None',
	argNames = ('index', 'count', 'v',),
)

glVertexAttribs1svNV = platform.createExtensionFunction( 
	'glVertexAttribs1svNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLsizei, arrays.GLshortArray,),
	doc = 'glVertexAttribs1svNV( GLuint(index), GLsizei(count), GLshortArray(v) ) -> None',
	argNames = ('index', 'count', 'v',),
)

glVertexAttribs2dvNV = platform.createExtensionFunction( 
	'glVertexAttribs2dvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLsizei, arrays.GLdoubleArray,),
	doc = 'glVertexAttribs2dvNV( GLuint(index), GLsizei(count), GLdoubleArray(v) ) -> None',
	argNames = ('index', 'count', 'v',),
)

glVertexAttribs2fvNV = platform.createExtensionFunction( 
	'glVertexAttribs2fvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLsizei, arrays.GLfloatArray,),
	doc = 'glVertexAttribs2fvNV( GLuint(index), GLsizei(count), GLfloatArray(v) ) -> None',
	argNames = ('index', 'count', 'v',),
)

glVertexAttribs2svNV = platform.createExtensionFunction( 
	'glVertexAttribs2svNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLsizei, arrays.GLshortArray,),
	doc = 'glVertexAttribs2svNV( GLuint(index), GLsizei(count), GLshortArray(v) ) -> None',
	argNames = ('index', 'count', 'v',),
)

glVertexAttribs3dvNV = platform.createExtensionFunction( 
	'glVertexAttribs3dvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLsizei, arrays.GLdoubleArray,),
	doc = 'glVertexAttribs3dvNV( GLuint(index), GLsizei(count), GLdoubleArray(v) ) -> None',
	argNames = ('index', 'count', 'v',),
)

glVertexAttribs3fvNV = platform.createExtensionFunction( 
	'glVertexAttribs3fvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLsizei, arrays.GLfloatArray,),
	doc = 'glVertexAttribs3fvNV( GLuint(index), GLsizei(count), GLfloatArray(v) ) -> None',
	argNames = ('index', 'count', 'v',),
)

glVertexAttribs3svNV = platform.createExtensionFunction( 
	'glVertexAttribs3svNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLsizei, arrays.GLshortArray,),
	doc = 'glVertexAttribs3svNV( GLuint(index), GLsizei(count), GLshortArray(v) ) -> None',
	argNames = ('index', 'count', 'v',),
)

glVertexAttribs4dvNV = platform.createExtensionFunction( 
	'glVertexAttribs4dvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLsizei, arrays.GLdoubleArray,),
	doc = 'glVertexAttribs4dvNV( GLuint(index), GLsizei(count), GLdoubleArray(v) ) -> None',
	argNames = ('index', 'count', 'v',),
)

glVertexAttribs4fvNV = platform.createExtensionFunction( 
	'glVertexAttribs4fvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLsizei, arrays.GLfloatArray,),
	doc = 'glVertexAttribs4fvNV( GLuint(index), GLsizei(count), GLfloatArray(v) ) -> None',
	argNames = ('index', 'count', 'v',),
)

glVertexAttribs4svNV = platform.createExtensionFunction( 
	'glVertexAttribs4svNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLsizei, arrays.GLshortArray,),
	doc = 'glVertexAttribs4svNV( GLuint(index), GLsizei(count), GLshortArray(v) ) -> None',
	argNames = ('index', 'count', 'v',),
)

glVertexAttribs4ubvNV = platform.createExtensionFunction( 
	'glVertexAttribs4ubvNV', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLsizei, arrays.GLubyteArray,),
	doc = 'glVertexAttribs4ubvNV( GLuint(index), GLsizei(count), GLubyteArray(v) ) -> None',
	argNames = ('index', 'count', 'v',),
)


def glInitVertexProgramNV():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.vertex_program

Overview (from the spec)
	
	Unextended OpenGL mandates a certain set of configurable per-vertex
	computations defining vertex transformation, texture coordinate generation
	and transformation, and lighting.  Several extensions have added further
	per-vertex computations to OpenGL.  For example, extensions have defined
	new texture coordinate generation modes (ARB_texture_cube_map,
	NV_texgen_reflection, NV_texgen_emboss), new vertex transformation modes
	(ARB_vertex_blend, EXT_vertex_weighting), new lighting modes (OpenGL 1.2's
	separate specular and rescale normal functionality), several modes for fog
	distance generation (NV_fog_distance), and eye-distance point size
	attenuation (EXT/ARB_point_parameters).
	
	Each such extension adds a small set of relatively inflexible
	per-vertex computations.
	
	This inflexibility is in contrast to the typical flexibility provided by
	the underlying programmable floating point engines (whether micro-coded
	vertex engines, DSPs, or CPUs) that are traditionally used to implement
	OpenGL's per-vertex computations.  The purpose of this extension is to
	expose to the OpenGL application writer a significant degree of per-vertex
	programmability for computing vertex parameters.
	
	For the purposes of discussing this extension, a vertex program is a
	sequence of floating-point 4-component vector operations that determines
	how a set of program parameters (defined outside of OpenGL's Begin/End
	pair) and an input set of per-vertex parameters are transformed to a set
	of per-vertex result parameters.
	
	The per-vertex computations for standard OpenGL given a particular set of
	lighting and texture coordinate generation modes (along with any state for
	extensions defining per-vertex computations) is, in essence, a vertex
	program.  However, the sequence of operations is defined implicitly by the
	current OpenGL state settings rather than defined explicitly as a sequence
	of instructions.
	
	This extension provides an explicit mechanism for defining vertex program
	instruction sequences for application-defined vertex programs.  In order
	to define such vertex programs, this extension defines a vertex
	programming model including a floating-point 4-component vector
	instruction set and a relatively large set of floating-point 4-component
	registers.
	
	The extension's vertex programming model is designed for efficient
	hardware implementation and to support a wide variety of vertex programs.
	By design, the entire set of existing vertex programs defined by existing
	OpenGL per-vertex computation extensions can be implemented using the
	extension's vertex programming model.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/ARB/vertex_program.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_vertex_program'
GL_COLOR_SUM_ARB = constant.Constant( 'GL_COLOR_SUM_ARB', 0x8458 )
glget.addGLGetConstant( GL_COLOR_SUM_ARB, (1,) )
GL_VERTEX_PROGRAM_ARB = constant.Constant( 'GL_VERTEX_PROGRAM_ARB', 0x8620 )
glget.addGLGetConstant( GL_VERTEX_PROGRAM_ARB, (1,) )
GL_VERTEX_ATTRIB_ARRAY_ENABLED_ARB = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY_ENABLED_ARB', 0x8622 )
GL_VERTEX_ATTRIB_ARRAY_SIZE_ARB = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY_SIZE_ARB', 0x8623 )
GL_VERTEX_ATTRIB_ARRAY_STRIDE_ARB = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY_STRIDE_ARB', 0x8624 )
GL_VERTEX_ATTRIB_ARRAY_TYPE_ARB = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY_TYPE_ARB', 0x8625 )
GL_CURRENT_VERTEX_ATTRIB_ARB = constant.Constant( 'GL_CURRENT_VERTEX_ATTRIB_ARB', 0x8626 )
GL_PROGRAM_LENGTH_ARB = constant.Constant( 'GL_PROGRAM_LENGTH_ARB', 0x8627 )
GL_PROGRAM_STRING_ARB = constant.Constant( 'GL_PROGRAM_STRING_ARB', 0x8628 )
GL_MAX_PROGRAM_MATRIX_STACK_DEPTH_ARB = constant.Constant( 'GL_MAX_PROGRAM_MATRIX_STACK_DEPTH_ARB', 0x862E )
glget.addGLGetConstant( GL_MAX_PROGRAM_MATRIX_STACK_DEPTH_ARB, (1,) )
GL_MAX_PROGRAM_MATRICES_ARB = constant.Constant( 'GL_MAX_PROGRAM_MATRICES_ARB', 0x862F )
glget.addGLGetConstant( GL_MAX_PROGRAM_MATRICES_ARB, (1,) )
GL_CURRENT_MATRIX_STACK_DEPTH_ARB = constant.Constant( 'GL_CURRENT_MATRIX_STACK_DEPTH_ARB', 0x8640 )
glget.addGLGetConstant( GL_CURRENT_MATRIX_STACK_DEPTH_ARB, (1,) )
GL_CURRENT_MATRIX_ARB = constant.Constant( 'GL_CURRENT_MATRIX_ARB', 0x8641 )
glget.addGLGetConstant( GL_CURRENT_MATRIX_ARB, (4,4) )
GL_VERTEX_PROGRAM_POINT_SIZE_ARB = constant.Constant( 'GL_VERTEX_PROGRAM_POINT_SIZE_ARB', 0x8642 )
glget.addGLGetConstant( GL_VERTEX_PROGRAM_POINT_SIZE_ARB, (1,) )
GL_VERTEX_PROGRAM_TWO_SIDE_ARB = constant.Constant( 'GL_VERTEX_PROGRAM_TWO_SIDE_ARB', 0x8643 )
glget.addGLGetConstant( GL_VERTEX_PROGRAM_TWO_SIDE_ARB, (1,) )
GL_VERTEX_ATTRIB_ARRAY_POINTER_ARB = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY_POINTER_ARB', 0x8645 )
GL_PROGRAM_ERROR_POSITION_ARB = constant.Constant( 'GL_PROGRAM_ERROR_POSITION_ARB', 0x864B )
glget.addGLGetConstant( GL_PROGRAM_ERROR_POSITION_ARB, (1,) )
GL_PROGRAM_BINDING_ARB = constant.Constant( 'GL_PROGRAM_BINDING_ARB', 0x8677 )
GL_MAX_VERTEX_ATTRIBS_ARB = constant.Constant( 'GL_MAX_VERTEX_ATTRIBS_ARB', 0x8869 )
glget.addGLGetConstant( GL_MAX_VERTEX_ATTRIBS_ARB, (1,) )
GL_VERTEX_ATTRIB_ARRAY_NORMALIZED_ARB = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY_NORMALIZED_ARB', 0x886A )
GL_PROGRAM_ERROR_STRING_ARB = constant.Constant( 'GL_PROGRAM_ERROR_STRING_ARB', 0x8874 )
GL_PROGRAM_FORMAT_ASCII_ARB = constant.Constant( 'GL_PROGRAM_FORMAT_ASCII_ARB', 0x8875 )
GL_PROGRAM_FORMAT_ARB = constant.Constant( 'GL_PROGRAM_FORMAT_ARB', 0x8876 )
GL_PROGRAM_INSTRUCTIONS_ARB = constant.Constant( 'GL_PROGRAM_INSTRUCTIONS_ARB', 0x88A0 )
GL_MAX_PROGRAM_INSTRUCTIONS_ARB = constant.Constant( 'GL_MAX_PROGRAM_INSTRUCTIONS_ARB', 0x88A1 )
GL_PROGRAM_NATIVE_INSTRUCTIONS_ARB = constant.Constant( 'GL_PROGRAM_NATIVE_INSTRUCTIONS_ARB', 0x88A2 )
GL_MAX_PROGRAM_NATIVE_INSTRUCTIONS_ARB = constant.Constant( 'GL_MAX_PROGRAM_NATIVE_INSTRUCTIONS_ARB', 0x88A3 )
GL_PROGRAM_TEMPORARIES_ARB = constant.Constant( 'GL_PROGRAM_TEMPORARIES_ARB', 0x88A4 )
GL_MAX_PROGRAM_TEMPORARIES_ARB = constant.Constant( 'GL_MAX_PROGRAM_TEMPORARIES_ARB', 0x88A5 )
GL_PROGRAM_NATIVE_TEMPORARIES_ARB = constant.Constant( 'GL_PROGRAM_NATIVE_TEMPORARIES_ARB', 0x88A6 )
GL_MAX_PROGRAM_NATIVE_TEMPORARIES_ARB = constant.Constant( 'GL_MAX_PROGRAM_NATIVE_TEMPORARIES_ARB', 0x88A7 )
GL_PROGRAM_PARAMETERS_ARB = constant.Constant( 'GL_PROGRAM_PARAMETERS_ARB', 0x88A8 )
GL_MAX_PROGRAM_PARAMETERS_ARB = constant.Constant( 'GL_MAX_PROGRAM_PARAMETERS_ARB', 0x88A9 )
GL_PROGRAM_NATIVE_PARAMETERS_ARB = constant.Constant( 'GL_PROGRAM_NATIVE_PARAMETERS_ARB', 0x88AA )
GL_MAX_PROGRAM_NATIVE_PARAMETERS_ARB = constant.Constant( 'GL_MAX_PROGRAM_NATIVE_PARAMETERS_ARB', 0x88AB )
GL_PROGRAM_ATTRIBS_ARB = constant.Constant( 'GL_PROGRAM_ATTRIBS_ARB', 0x88AC )
GL_MAX_PROGRAM_ATTRIBS_ARB = constant.Constant( 'GL_MAX_PROGRAM_ATTRIBS_ARB', 0x88AD )
GL_PROGRAM_NATIVE_ATTRIBS_ARB = constant.Constant( 'GL_PROGRAM_NATIVE_ATTRIBS_ARB', 0x88AE )
GL_MAX_PROGRAM_NATIVE_ATTRIBS_ARB = constant.Constant( 'GL_MAX_PROGRAM_NATIVE_ATTRIBS_ARB', 0x88AF )
GL_PROGRAM_ADDRESS_REGISTERS_ARB = constant.Constant( 'GL_PROGRAM_ADDRESS_REGISTERS_ARB', 0x88B0 )
GL_MAX_PROGRAM_ADDRESS_REGISTERS_ARB = constant.Constant( 'GL_MAX_PROGRAM_ADDRESS_REGISTERS_ARB', 0x88B1 )
GL_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB = constant.Constant( 'GL_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB', 0x88B2 )
GL_MAX_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB = constant.Constant( 'GL_MAX_PROGRAM_NATIVE_ADDRESS_REGISTERS_ARB', 0x88B3 )
GL_MAX_PROGRAM_LOCAL_PARAMETERS_ARB = constant.Constant( 'GL_MAX_PROGRAM_LOCAL_PARAMETERS_ARB', 0x88B4 )
GL_MAX_PROGRAM_ENV_PARAMETERS_ARB = constant.Constant( 'GL_MAX_PROGRAM_ENV_PARAMETERS_ARB', 0x88B5 )
GL_PROGRAM_UNDER_NATIVE_LIMITS_ARB = constant.Constant( 'GL_PROGRAM_UNDER_NATIVE_LIMITS_ARB', 0x88B6 )
GL_TRANSPOSE_CURRENT_MATRIX_ARB = constant.Constant( 'GL_TRANSPOSE_CURRENT_MATRIX_ARB', 0x88B7 )
glget.addGLGetConstant( GL_TRANSPOSE_CURRENT_MATRIX_ARB, (4,4) )
GL_MATRIX0_ARB = constant.Constant( 'GL_MATRIX0_ARB', 0x88C0 )
GL_MATRIX1_ARB = constant.Constant( 'GL_MATRIX1_ARB', 0x88C1 )
GL_MATRIX2_ARB = constant.Constant( 'GL_MATRIX2_ARB', 0x88C2 )
GL_MATRIX3_ARB = constant.Constant( 'GL_MATRIX3_ARB', 0x88C3 )
GL_MATRIX4_ARB = constant.Constant( 'GL_MATRIX4_ARB', 0x88C4 )
GL_MATRIX5_ARB = constant.Constant( 'GL_MATRIX5_ARB', 0x88C5 )
GL_MATRIX6_ARB = constant.Constant( 'GL_MATRIX6_ARB', 0x88C6 )
GL_MATRIX7_ARB = constant.Constant( 'GL_MATRIX7_ARB', 0x88C7 )
GL_MATRIX8_ARB = constant.Constant( 'GL_MATRIX8_ARB', 0x88C8 )
GL_MATRIX9_ARB = constant.Constant( 'GL_MATRIX9_ARB', 0x88C9 )
GL_MATRIX10_ARB = constant.Constant( 'GL_MATRIX10_ARB', 0x88CA )
GL_MATRIX11_ARB = constant.Constant( 'GL_MATRIX11_ARB', 0x88CB )
GL_MATRIX12_ARB = constant.Constant( 'GL_MATRIX12_ARB', 0x88CC )
GL_MATRIX13_ARB = constant.Constant( 'GL_MATRIX13_ARB', 0x88CD )
GL_MATRIX14_ARB = constant.Constant( 'GL_MATRIX14_ARB', 0x88CE )
GL_MATRIX15_ARB = constant.Constant( 'GL_MATRIX15_ARB', 0x88CF )
GL_MATRIX16_ARB = constant.Constant( 'GL_MATRIX16_ARB', 0x88D0 )
GL_MATRIX17_ARB = constant.Constant( 'GL_MATRIX17_ARB', 0x88D1 )
GL_MATRIX18_ARB = constant.Constant( 'GL_MATRIX18_ARB', 0x88D2 )
GL_MATRIX19_ARB = constant.Constant( 'GL_MATRIX19_ARB', 0x88D3 )
GL_MATRIX20_ARB = constant.Constant( 'GL_MATRIX20_ARB', 0x88D4 )
GL_MATRIX21_ARB = constant.Constant( 'GL_MATRIX21_ARB', 0x88D5 )
GL_MATRIX22_ARB = constant.Constant( 'GL_MATRIX22_ARB', 0x88D6 )
GL_MATRIX23_ARB = constant.Constant( 'GL_MATRIX23_ARB', 0x88D7 )
GL_MATRIX24_ARB = constant.Constant( 'GL_MATRIX24_ARB', 0x88D8 )
GL_MATRIX25_ARB = constant.Constant( 'GL_MATRIX25_ARB', 0x88D9 )
GL_MATRIX26_ARB = constant.Constant( 'GL_MATRIX26_ARB', 0x88DA )
GL_MATRIX27_ARB = constant.Constant( 'GL_MATRIX27_ARB', 0x88DB )
GL_MATRIX28_ARB = constant.Constant( 'GL_MATRIX28_ARB', 0x88DC )
GL_MATRIX29_ARB = constant.Constant( 'GL_MATRIX29_ARB', 0x88DD )
GL_MATRIX30_ARB = constant.Constant( 'GL_MATRIX30_ARB', 0x88DE )
GL_MATRIX31_ARB = constant.Constant( 'GL_MATRIX31_ARB', 0x88DF )
glVertexAttrib1dARB = platform.createExtensionFunction( 
	'glVertexAttrib1dARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLdouble,),
	doc = 'glVertexAttrib1dARB( GLuint(index), GLdouble(x) ) -> None',
	argNames = ('index', 'x',),
)

glVertexAttrib1dvARB = platform.createExtensionFunction( 
	'glVertexAttrib1dvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLdoubleArray,),
	doc = 'glVertexAttrib1dvARB( GLuint(index), GLdoubleArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib1fARB = platform.createExtensionFunction( 
	'glVertexAttrib1fARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLfloat,),
	doc = 'glVertexAttrib1fARB( GLuint(index), GLfloat(x) ) -> None',
	argNames = ('index', 'x',),
)

glVertexAttrib1fvARB = platform.createExtensionFunction( 
	'glVertexAttrib1fvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLfloatArray,),
	doc = 'glVertexAttrib1fvARB( GLuint(index), GLfloatArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib1sARB = platform.createExtensionFunction( 
	'glVertexAttrib1sARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLshort,),
	doc = 'glVertexAttrib1sARB( GLuint(index), GLshort(x) ) -> None',
	argNames = ('index', 'x',),
)

glVertexAttrib1svARB = platform.createExtensionFunction( 
	'glVertexAttrib1svARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLshortArray,),
	doc = 'glVertexAttrib1svARB( GLuint(index), GLshortArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib2dARB = platform.createExtensionFunction( 
	'glVertexAttrib2dARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLdouble, constants.GLdouble,),
	doc = 'glVertexAttrib2dARB( GLuint(index), GLdouble(x), GLdouble(y) ) -> None',
	argNames = ('index', 'x', 'y',),
)

glVertexAttrib2dvARB = platform.createExtensionFunction( 
	'glVertexAttrib2dvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLdoubleArray,),
	doc = 'glVertexAttrib2dvARB( GLuint(index), GLdoubleArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib2fARB = platform.createExtensionFunction( 
	'glVertexAttrib2fARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLfloat, constants.GLfloat,),
	doc = 'glVertexAttrib2fARB( GLuint(index), GLfloat(x), GLfloat(y) ) -> None',
	argNames = ('index', 'x', 'y',),
)

glVertexAttrib2fvARB = platform.createExtensionFunction( 
	'glVertexAttrib2fvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLfloatArray,),
	doc = 'glVertexAttrib2fvARB( GLuint(index), GLfloatArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib2sARB = platform.createExtensionFunction( 
	'glVertexAttrib2sARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLshort, constants.GLshort,),
	doc = 'glVertexAttrib2sARB( GLuint(index), GLshort(x), GLshort(y) ) -> None',
	argNames = ('index', 'x', 'y',),
)

glVertexAttrib2svARB = platform.createExtensionFunction( 
	'glVertexAttrib2svARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLshortArray,),
	doc = 'glVertexAttrib2svARB( GLuint(index), GLshortArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib3dARB = platform.createExtensionFunction( 
	'glVertexAttrib3dARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLdouble, constants.GLdouble, constants.GLdouble,),
	doc = 'glVertexAttrib3dARB( GLuint(index), GLdouble(x), GLdouble(y), GLdouble(z) ) -> None',
	argNames = ('index', 'x', 'y', 'z',),
)

glVertexAttrib3dvARB = platform.createExtensionFunction( 
	'glVertexAttrib3dvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLdoubleArray,),
	doc = 'glVertexAttrib3dvARB( GLuint(index), GLdoubleArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib3fARB = platform.createExtensionFunction( 
	'glVertexAttrib3fARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glVertexAttrib3fARB( GLuint(index), GLfloat(x), GLfloat(y), GLfloat(z) ) -> None',
	argNames = ('index', 'x', 'y', 'z',),
)

glVertexAttrib3fvARB = platform.createExtensionFunction( 
	'glVertexAttrib3fvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLfloatArray,),
	doc = 'glVertexAttrib3fvARB( GLuint(index), GLfloatArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib3sARB = platform.createExtensionFunction( 
	'glVertexAttrib3sARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLshort, constants.GLshort, constants.GLshort,),
	doc = 'glVertexAttrib3sARB( GLuint(index), GLshort(x), GLshort(y), GLshort(z) ) -> None',
	argNames = ('index', 'x', 'y', 'z',),
)

glVertexAttrib3svARB = platform.createExtensionFunction( 
	'glVertexAttrib3svARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLshortArray,),
	doc = 'glVertexAttrib3svARB( GLuint(index), GLshortArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib4NbvARB = platform.createExtensionFunction( 
	'glVertexAttrib4NbvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLbyteArray,),
	doc = 'glVertexAttrib4NbvARB( GLuint(index), GLbyteArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib4NivARB = platform.createExtensionFunction( 
	'glVertexAttrib4NivARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLintArray,),
	doc = 'glVertexAttrib4NivARB( GLuint(index), GLintArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib4NsvARB = platform.createExtensionFunction( 
	'glVertexAttrib4NsvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLshortArray,),
	doc = 'glVertexAttrib4NsvARB( GLuint(index), GLshortArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib4NubARB = platform.createExtensionFunction( 
	'glVertexAttrib4NubARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLubyte, constants.GLubyte, constants.GLubyte, constants.GLubyte,),
	doc = 'glVertexAttrib4NubARB( GLuint(index), GLubyte(x), GLubyte(y), GLubyte(z), GLubyte(w) ) -> None',
	argNames = ('index', 'x', 'y', 'z', 'w',),
)

glVertexAttrib4NubvARB = platform.createExtensionFunction( 
	'glVertexAttrib4NubvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLubyteArray,),
	doc = 'glVertexAttrib4NubvARB( GLuint(index), GLubyteArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib4NuivARB = platform.createExtensionFunction( 
	'glVertexAttrib4NuivARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLuintArray,),
	doc = 'glVertexAttrib4NuivARB( GLuint(index), GLuintArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib4NusvARB = platform.createExtensionFunction( 
	'glVertexAttrib4NusvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLushortArray,),
	doc = 'glVertexAttrib4NusvARB( GLuint(index), GLushortArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib4bvARB = platform.createExtensionFunction( 
	'glVertexAttrib4bvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLbyteArray,),
	doc = 'glVertexAttrib4bvARB( GLuint(index), GLbyteArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib4dARB = platform.createExtensionFunction( 
	'glVertexAttrib4dARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLdouble, constants.GLdouble, constants.GLdouble, constants.GLdouble,),
	doc = 'glVertexAttrib4dARB( GLuint(index), GLdouble(x), GLdouble(y), GLdouble(z), GLdouble(w) ) -> None',
	argNames = ('index', 'x', 'y', 'z', 'w',),
)

glVertexAttrib4dvARB = platform.createExtensionFunction( 
	'glVertexAttrib4dvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLdoubleArray,),
	doc = 'glVertexAttrib4dvARB( GLuint(index), GLdoubleArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib4fARB = platform.createExtensionFunction( 
	'glVertexAttrib4fARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glVertexAttrib4fARB( GLuint(index), GLfloat(x), GLfloat(y), GLfloat(z), GLfloat(w) ) -> None',
	argNames = ('index', 'x', 'y', 'z', 'w',),
)

glVertexAttrib4fvARB = platform.createExtensionFunction( 
	'glVertexAttrib4fvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLfloatArray,),
	doc = 'glVertexAttrib4fvARB( GLuint(index), GLfloatArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib4ivARB = platform.createExtensionFunction( 
	'glVertexAttrib4ivARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLintArray,),
	doc = 'glVertexAttrib4ivARB( GLuint(index), GLintArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib4sARB = platform.createExtensionFunction( 
	'glVertexAttrib4sARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLshort, constants.GLshort, constants.GLshort, constants.GLshort,),
	doc = 'glVertexAttrib4sARB( GLuint(index), GLshort(x), GLshort(y), GLshort(z), GLshort(w) ) -> None',
	argNames = ('index', 'x', 'y', 'z', 'w',),
)

glVertexAttrib4svARB = platform.createExtensionFunction( 
	'glVertexAttrib4svARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLshortArray,),
	doc = 'glVertexAttrib4svARB( GLuint(index), GLshortArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib4ubvARB = platform.createExtensionFunction( 
	'glVertexAttrib4ubvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLubyteArray,),
	doc = 'glVertexAttrib4ubvARB( GLuint(index), GLubyteArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib4uivARB = platform.createExtensionFunction( 
	'glVertexAttrib4uivARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLuintArray,),
	doc = 'glVertexAttrib4uivARB( GLuint(index), GLuintArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttrib4usvARB = platform.createExtensionFunction( 
	'glVertexAttrib4usvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, arrays.GLushortArray,),
	doc = 'glVertexAttrib4usvARB( GLuint(index), GLushortArray(v) ) -> None',
	argNames = ('index', 'v',),
)

glVertexAttribPointerARB = platform.createExtensionFunction( 
	'glVertexAttribPointerARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLint, constants.GLenum, constants.GLboolean, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glVertexAttribPointerARB( GLuint(index), GLint(size), GLenum(type), GLboolean(normalized), GLsizei(stride), c_void_p(pointer) ) -> None',
	argNames = ('index', 'size', 'type', 'normalized', 'stride', 'pointer',),
)

glEnableVertexAttribArrayARB = platform.createExtensionFunction( 
	'glEnableVertexAttribArrayARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint,),
	doc = 'glEnableVertexAttribArrayARB( GLuint(index) ) -> None',
	argNames = ('index',),
)

glDisableVertexAttribArrayARB = platform.createExtensionFunction( 
	'glDisableVertexAttribArrayARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint,),
	doc = 'glDisableVertexAttribArrayARB( GLuint(index) ) -> None',
	argNames = ('index',),
)

glProgramStringARB = platform.createExtensionFunction( 
	'glProgramStringARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, constants.GLsizei, ctypes.c_void_p,),
	doc = 'glProgramStringARB( GLenum(target), GLenum(format), GLsizei(len), c_void_p(string) ) -> None',
	argNames = ('target', 'format', 'len', 'string',),
)

glBindProgramARB = platform.createExtensionFunction( 
	'glBindProgramARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint,),
	doc = 'glBindProgramARB( GLenum(target), GLuint(program) ) -> None',
	argNames = ('target', 'program',),
)

glDeleteProgramsARB = platform.createExtensionFunction( 
	'glDeleteProgramsARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLsizei, arrays.GLuintArray,),
	doc = 'glDeleteProgramsARB( GLsizei(n), GLuintArray(programs) ) -> None',
	argNames = ('n', 'programs',),
)

glGenProgramsARB = platform.createExtensionFunction( 
	'glGenProgramsARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLsizei, arrays.GLuintArray,),
	doc = 'glGenProgramsARB( GLsizei(n), GLuintArray(programs) ) -> None',
	argNames = ('n', 'programs',),
)

glProgramEnvParameter4dARB = platform.createExtensionFunction( 
	'glProgramEnvParameter4dARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, constants.GLdouble, constants.GLdouble, constants.GLdouble, constants.GLdouble,),
	doc = 'glProgramEnvParameter4dARB( GLenum(target), GLuint(index), GLdouble(x), GLdouble(y), GLdouble(z), GLdouble(w) ) -> None',
	argNames = ('target', 'index', 'x', 'y', 'z', 'w',),
)

glProgramEnvParameter4dvARB = platform.createExtensionFunction( 
	'glProgramEnvParameter4dvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, arrays.GLdoubleArray,),
	doc = 'glProgramEnvParameter4dvARB( GLenum(target), GLuint(index), GLdoubleArray(params) ) -> None',
	argNames = ('target', 'index', 'params',),
)

glProgramEnvParameter4fARB = platform.createExtensionFunction( 
	'glProgramEnvParameter4fARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glProgramEnvParameter4fARB( GLenum(target), GLuint(index), GLfloat(x), GLfloat(y), GLfloat(z), GLfloat(w) ) -> None',
	argNames = ('target', 'index', 'x', 'y', 'z', 'w',),
)

glProgramEnvParameter4fvARB = platform.createExtensionFunction( 
	'glProgramEnvParameter4fvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, arrays.GLfloatArray,),
	doc = 'glProgramEnvParameter4fvARB( GLenum(target), GLuint(index), GLfloatArray(params) ) -> None',
	argNames = ('target', 'index', 'params',),
)

glProgramLocalParameter4dARB = platform.createExtensionFunction( 
	'glProgramLocalParameter4dARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, constants.GLdouble, constants.GLdouble, constants.GLdouble, constants.GLdouble,),
	doc = 'glProgramLocalParameter4dARB( GLenum(target), GLuint(index), GLdouble(x), GLdouble(y), GLdouble(z), GLdouble(w) ) -> None',
	argNames = ('target', 'index', 'x', 'y', 'z', 'w',),
)

glProgramLocalParameter4dvARB = platform.createExtensionFunction( 
	'glProgramLocalParameter4dvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, arrays.GLdoubleArray,),
	doc = 'glProgramLocalParameter4dvARB( GLenum(target), GLuint(index), GLdoubleArray(params) ) -> None',
	argNames = ('target', 'index', 'params',),
)

glProgramLocalParameter4fARB = platform.createExtensionFunction( 
	'glProgramLocalParameter4fARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, constants.GLfloat, constants.GLfloat, constants.GLfloat, constants.GLfloat,),
	doc = 'glProgramLocalParameter4fARB( GLenum(target), GLuint(index), GLfloat(x), GLfloat(y), GLfloat(z), GLfloat(w) ) -> None',
	argNames = ('target', 'index', 'x', 'y', 'z', 'w',),
)

glProgramLocalParameter4fvARB = platform.createExtensionFunction( 
	'glProgramLocalParameter4fvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, arrays.GLfloatArray,),
	doc = 'glProgramLocalParameter4fvARB( GLenum(target), GLuint(index), GLfloatArray(params) ) -> None',
	argNames = ('target', 'index', 'params',),
)

glGetProgramEnvParameterdvARB = platform.createExtensionFunction( 
	'glGetProgramEnvParameterdvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, arrays.GLdoubleArray,),
	doc = 'glGetProgramEnvParameterdvARB( GLenum(target), GLuint(index), GLdoubleArray(params) ) -> None',
	argNames = ('target', 'index', 'params',),
)

glGetProgramEnvParameterfvARB = platform.createExtensionFunction( 
	'glGetProgramEnvParameterfvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, arrays.GLfloatArray,),
	doc = 'glGetProgramEnvParameterfvARB( GLenum(target), GLuint(index), GLfloatArray(params) ) -> None',
	argNames = ('target', 'index', 'params',),
)

glGetProgramLocalParameterdvARB = platform.createExtensionFunction( 
	'glGetProgramLocalParameterdvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, arrays.GLdoubleArray,),
	doc = 'glGetProgramLocalParameterdvARB( GLenum(target), GLuint(index), GLdoubleArray(params) ) -> None',
	argNames = ('target', 'index', 'params',),
)

glGetProgramLocalParameterfvARB = platform.createExtensionFunction( 
	'glGetProgramLocalParameterfvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLuint, arrays.GLfloatArray,),
	doc = 'glGetProgramLocalParameterfvARB( GLenum(target), GLuint(index), GLfloatArray(params) ) -> None',
	argNames = ('target', 'index', 'params',),
)

glGetProgramivARB = platform.createExtensionFunction( 
	'glGetProgramivARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, arrays.GLintArray,),
	doc = 'glGetProgramivARB( GLenum(target), GLenum(pname), GLintArray(params) ) -> None',
	argNames = ('target', 'pname', 'params',),
)

glGetProgramStringARB = platform.createExtensionFunction( 
	'glGetProgramStringARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLenum, constants.GLenum, ctypes.c_void_p,),
	doc = 'glGetProgramStringARB( GLenum(target), GLenum(pname), c_void_p(string) ) -> None',
	argNames = ('target', 'pname', 'string',),
)

glGetVertexAttribdvARB = platform.createExtensionFunction( 
	'glGetVertexAttribdvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLenum, arrays.GLdoubleArray,),
	doc = 'glGetVertexAttribdvARB( GLuint(index), GLenum(pname), GLdoubleArray(params) ) -> None',
	argNames = ('index', 'pname', 'params',),
)

glGetVertexAttribfvARB = platform.createExtensionFunction( 
	'glGetVertexAttribfvARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLenum, arrays.GLfloatArray,),
	doc = 'glGetVertexAttribfvARB( GLuint(index), GLenum(pname), GLfloatArray(params) ) -> None',
	argNames = ('index', 'pname', 'params',),
)

glGetVertexAttribivARB = platform.createExtensionFunction( 
	'glGetVertexAttribivARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLenum, arrays.GLintArray,),
	doc = 'glGetVertexAttribivARB( GLuint(index), GLenum(pname), GLintArray(params) ) -> None',
	argNames = ('index', 'pname', 'params',),
)

glGetVertexAttribPointervARB = platform.createExtensionFunction( 
	'glGetVertexAttribPointervARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=None, 
	argTypes=(constants.GLuint, constants.GLenum, ctypes.POINTER(ctypes.c_void_p),),
	doc = 'glGetVertexAttribPointervARB( GLuint(index), GLenum(pname), POINTER(ctypes.c_void_p)(pointer) ) -> None',
	argNames = ('index', 'pname', 'pointer',),
)

glIsProgramARB = platform.createExtensionFunction( 
	'glIsProgramARB', dll=platform.GL,
	extension=EXTENSION_NAME,
	resultType=constants.GLboolean, 
	argTypes=(constants.GLuint,),
	doc = 'glIsProgramARB( GLuint(program) ) -> constants.GLboolean',
	argNames = ('program',),
)


def glInitVertexProgramARB():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.texture_env_combine

Overview (from the spec)
	
	New texture environment function COMBINE_ARB allows programmable
	texture combiner operations, including:
	
	    REPLACE                 Arg0
	    MODULATE                Arg0 * Arg1
	    ADD                     Arg0 + Arg1
	    ADD_SIGNED_ARB          Arg0 + Arg1 - 0.5
	    SUBTRACT_ARB            Arg0 - Arg1
	    INTERPOLATE_ARB         Arg0 * (Arg2) + Arg1 * (1-Arg2)
	
	where Arg0, Arg1 and Arg2 are derived from
	
	    PRIMARY_COLOR_ARB       primary color of incoming fragment
	    TEXTURE                 texture color of corresponding texture unit
	    CONSTANT_ARB            texture environment constant color
	    PREVIOUS_ARB            result of previous texture environment; on
	                            texture unit 0, this maps to PRIMARY_COLOR_ARB
	
	In addition, the result may be scaled by 1.0, 2.0 or 4.0.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/ARB/texture_env_combine.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_texture_env_combine'
GL_COMBINE_ARB = constant.Constant( 'GL_COMBINE_ARB', 0x8570 )
GL_COMBINE_RGB_ARB = constant.Constant( 'GL_COMBINE_RGB_ARB', 0x8571 )
GL_COMBINE_ALPHA_ARB = constant.Constant( 'GL_COMBINE_ALPHA_ARB', 0x8572 )
GL_SOURCE0_RGB_ARB = constant.Constant( 'GL_SOURCE0_RGB_ARB', 0x8580 )
GL_SOURCE1_RGB_ARB = constant.Constant( 'GL_SOURCE1_RGB_ARB', 0x8581 )
GL_SOURCE2_RGB_ARB = constant.Constant( 'GL_SOURCE2_RGB_ARB', 0x8582 )
GL_SOURCE0_ALPHA_ARB = constant.Constant( 'GL_SOURCE0_ALPHA_ARB', 0x8588 )
GL_SOURCE1_ALPHA_ARB = constant.Constant( 'GL_SOURCE1_ALPHA_ARB', 0x8589 )
GL_SOURCE2_ALPHA_ARB = constant.Constant( 'GL_SOURCE2_ALPHA_ARB', 0x858A )
GL_OPERAND0_RGB_ARB = constant.Constant( 'GL_OPERAND0_RGB_ARB', 0x8590 )
GL_OPERAND1_RGB_ARB = constant.Constant( 'GL_OPERAND1_RGB_ARB', 0x8591 )
GL_OPERAND2_RGB_ARB = constant.Constant( 'GL_OPERAND2_RGB_ARB', 0x8592 )
GL_OPERAND0_ALPHA_ARB = constant.Constant( 'GL_OPERAND0_ALPHA_ARB', 0x8598 )
GL_OPERAND1_ALPHA_ARB = constant.Constant( 'GL_OPERAND1_ALPHA_ARB', 0x8599 )
GL_OPERAND2_ALPHA_ARB = constant.Constant( 'GL_OPERAND2_ALPHA_ARB', 0x859A )
GL_RGB_SCALE_ARB = constant.Constant( 'GL_RGB_SCALE_ARB', 0x8573 )
GL_ADD_SIGNED_ARB = constant.Constant( 'GL_ADD_SIGNED_ARB', 0x8574 )
GL_INTERPOLATE_ARB = constant.Constant( 'GL_INTERPOLATE_ARB', 0x8575 )
GL_SUBTRACT_ARB = constant.Constant( 'GL_SUBTRACT_ARB', 0x84E7 )
GL_CONSTANT_ARB = constant.Constant( 'GL_CONSTANT_ARB', 0x8576 )
GL_PRIMARY_COLOR_ARB = constant.Constant( 'GL_PRIMARY_COLOR_ARB', 0x8577 )
GL_PREVIOUS_ARB = constant.Constant( 'GL_PREVIOUS_ARB', 0x8578 )


def glInitTextureEnvCombineARB():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.packed_pixels

Overview (from the spec)
	
	This extension provides support for packed pixels in host memory.  A
	packed pixel is represented entirely by one unsigned byte, one
	unsigned short, or one unsigned integer.  The fields with the packed
	pixel are not proper machine types, but the pixel as a whole is.  Thus
	the pixel storage modes, including PACK_SKIP_PIXELS, PACK_ROW_LENGTH,
	PACK_SKIP_ROWS, PACK_IMAGE_HEIGHT_EXT, PACK_SKIP_IMAGES_EXT,
	PACK_SWAP_BYTES, PACK_ALIGNMENT, and their unpacking counterparts all
	work correctly with packed pixels.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/EXT/packed_pixels.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_packed_pixels'
GL_UNSIGNED_BYTE_3_3_2_EXT = constant.Constant( 'GL_UNSIGNED_BYTE_3_3_2_EXT', 0x8032 )
GL_UNSIGNED_SHORT_4_4_4_4_EXT = constant.Constant( 'GL_UNSIGNED_SHORT_4_4_4_4_EXT', 0x8033 )
GL_UNSIGNED_SHORT_5_5_5_1_EXT = constant.Constant( 'GL_UNSIGNED_SHORT_5_5_5_1_EXT', 0x8034 )
GL_UNSIGNED_INT_8_8_8_8_EXT = constant.Constant( 'GL_UNSIGNED_INT_8_8_8_8_EXT', 0x8035 )
GL_UNSIGNED_INT_10_10_10_2_EXT = constant.Constant( 'GL_UNSIGNED_INT_10_10_10_2_EXT', 0x8036 )


def glInitPackedPixelsEXT():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGIX.async_histogram

Overview (from the spec)
	
	This extension introduces a new asynchronous mode for histogram
	and minmax readbacks.  It allows programs to get the contents of a
	histogram or minmax table without blocking and to continue issuing
	graphics commands during the readback.

The official definition of this extension is available here:
	http://oss.sgi.com/projects/ogl-sample/registry/SGIX/async_histogram.txt

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_async_histogram'
GL_ASYNC_HISTOGRAM_SGIX = constant.Constant( 'GL_ASYNC_HISTOGRAM_SGIX', 0x832C )
glget.addGLGetConstant( GL_ASYNC_HISTOGRAM_SGIX, (1,) )
GL_MAX_ASYNC_HISTOGRAM_SGIX = constant.Constant( 'GL_MAX_ASYNC_HISTOGRAM_SGIX', 0x832D )
glget.addGLGetConstant( GL_MAX_ASYNC_HISTOGRAM_SGIX, (1,) )


def glInitAsyncHistogramSGIX():
	'''Return boolean indicating whether this extension is available'''
	return extensions.hasGLExtension( EXTENSION_NAME )



"""glu[Un]Project[4] convenience wrappers"""
from OpenGL.platform import GL
from OpenGL.raw import GLU as simple
from OpenGL import GL, arrays
from OpenGL.lazywrapper import lazy
import ctypes 
POINTER = ctypes.POINTER

@lazy( simple.gluProject )
def gluProject( baseFunction, objX, objY, objZ, model=None, proj=None, view=None ):
	"""Convenience wrapper for gluProject
	
	Automatically fills in the model, projection and viewing matrices
	if not provided.
	
	returns (winX,winY,winZ) doubles
	"""
	if model is None:
		model = GL.glGetDoublev( GL.GL_MODELVIEW_MATRIX )
	if proj is None:
		proj = GL.glGetDoublev( GL.GL_PROJECTION_MATRIX )
	if view is None:
		view = GL.glGetIntegerv( GL.GL_VIEWPORT )
	winX = simple.GLdouble( 0.0 )
	winY = simple.GLdouble( 0.0 )
	winZ = simple.GLdouble( 0.0 )
	result = baseFunction( 
		objX,objY,objZ,
		model,proj,view,
		winX,winY,winZ,
	)
	if not result:
		raise ValueError( """Projection failed!""" )
	return winX.value, winY.value, winZ.value 

@lazy( simple.gluUnProject )
def gluUnProject( baseFunction, winX, winY, winZ, model=None, proj=None, view=None ):
	"""Convenience wrapper for gluUnProject
	
	Automatically fills in the model, projection and viewing matrices
	if not provided.
	
	returns (objX,objY,objZ) doubles
	"""
	if model is None:
		model = GL.glGetDoublev( GL.GL_MODELVIEW_MATRIX )
	if proj is None:
		proj = GL.glGetDoublev( GL.GL_PROJECTION_MATRIX )
	if view is None:
		view = GL.glGetIntegerv( GL.GL_VIEWPORT )
	objX = simple.GLdouble( 0.0 )
	objY = simple.GLdouble( 0.0 )
	objZ = simple.GLdouble( 0.0 )
	result = baseFunction( 
		winX,winY,winZ,
		model,proj,view,
		ctypes.byref(objX),ctypes.byref(objY),ctypes.byref(objZ),
	)
	if not result:
		raise ValueError( """Projection failed!""" )
	return objX.value, objY.value, objZ.value 
@lazy( simple.gluUnProject4 )
def gluUnProject4(
	baseFunction,
	winX, winY, winZ, clipW, 
	model=None, proj=None, view=None, 
	near=0.0, far=1.0
):
	"""Convenience wrapper for gluUnProject
	
	Automatically fills in the model, projection and viewing matrices
	if not provided.
	
	returns (objX,objY,objZ) doubles
	"""
	if model is None:
		model = GL.glGetDoublev( GL.GL_MODELVIEW_MATRIX )
	if proj is None:
		proj = GL.glGetDoublev( GL.GL_PROJECTION_MATRIX )
	if view is None:
		view = GL.glGetIntegerv( GL.GL_VIEWPORT )
	objX = simple.GLdouble( 0.0 )
	objY = simple.GLdouble( 0.0 )
	objZ = simple.GLdouble( 0.0 )
	objW = simple.GLdouble( 0.0 )
	result = baseFunction( 
		winX,winY,winZ,
		model,proj,view,
		ctypes.byref(objX),ctypes.byref(objY),ctypes.byref(objZ),ctypes.byref(objW)
	)
	if not result:
		raise ValueError( """Projection failed!""" )
	return objX.value, objY.value, objZ.value, objW.value

__all__ = (
	'gluProject',
	'gluUnProject',
	'gluUnProject4',
)
